CustomerDetails class
- Annotations
-
- @JsonSerializable.new(createToJson: true, explicitToJson: true)
Constructors
- CustomerDetails({required String mCustomerId, required String name, required String email, required String mobile, required String code})
-
CustomerDetails.fromJson(Map<
String, dynamic> json) -
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited