PayOrcFlutter class
Properties
- checkOutId ↔ String?
-
Sets the order id
getter/setter pair
- configMemoryHolder ↔ ConfigMemoryHolder
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- orderId ↔ String?
-
Sets the order id
getter/setter pair
- preferenceHelper → PreferencesHelper
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId ↔ String?
-
Sets the logged-in user identifier
getter/setter pair
Methods
-
clearData(
) → Future< void> - Clear preference data
-
createPaymentWithWidget(
{required BuildContext context, required PayOrcPaymentRequest request, required dynamic errorResult(String? message), required dynamic onPopResult(String? message)}) → Future< void> - To create payment with widget
-
fetchPaymentTransaction(
{required String orderId, required dynamic onLoadingResult(bool loading), required dynamic errorResult(String? message)}) → Future< PayOrcPaymentTransactionResponse?> - To fetch payment transaction
-
getMerchantKey(
) → Future< String?> - Returns the current merchant key (a random GUID assigned to the app running on the device)
-
getMerchantSecret(
) → Future< String?> - Returns the current merchant secret (a random GUID assigned to the app running on the device)
-
getPlatformVersion(
) → Future< String?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → PayOrcFlutter
-
Retrieve the singleton instance
no setter
Static Methods
-
initialize(
{required Environment environment, required String merchantKey, required String merchantSecret}) → Future< PayOrcFlutter> - Factory constructor for asynchronous initialization